@@ -77,7 +77,7 @@ class ElasticsearchPublisher(Publisher):
         After upload, swap alias from {old_index} to {new_index} in a atomic operation
         to route traffic to {new_index}
         """
-        actions = [json.loads(l) for l in self.file_handler.readlines()]
+        actions = [json.loads(line) for line in self.file_handler.readlines()]
         # ensure new data exists
         if not actions:
             LOGGER.warning("received no data to upload to Elasticsearch!")
@@ -91,9 +91,11 @@ class ElasticsearchPublisher(Publisher):
 
         # create new index with mapping
         self.elasticsearch_client.indices.create(index=self.elasticsearch_new_index, body=self.elasticsearch_mapping)
+
         for action in actions:
-            index_row = dict(index=dict(_index=self.elasticsearch_new_index,
-                                        _type=self.elasticsearch_type))
+            index_row = dict(index=dict(_index=self.elasticsearch_new_index))
+            action['resource_type'] = self.elasticsearch_type
+
             bulk_actions.append(index_row)
             bulk_actions.append(action)
             cnt += 1
